From da3bf9b54b4e680ccbb1d677961f364d43f31627 Mon Sep 17 00:00:00 2001
From: Colin Watson <cjwatson@ubuntu.com>
Date: Tue, 7 Jul 2009 11:30:16 +0100
Subject: [PATCH 4/4] Add tests for Launchpad-Bugs-Fixed handling

---
 scripts/t/600_Dpkg_Changelog.t      |   35 ++++++++++++++++++++++++++++++++---
 scripts/t/600_Dpkg_Changelog/fields |    2 ++
 2 files changed, 34 insertions(+), 3 deletions(-)

diff --git a/scripts/t/600_Dpkg_Changelog.t b/scripts/t/600_Dpkg_Changelog.t
index 7182718..fdc458a 100644
--- a/scripts/t/600_Dpkg_Changelog.t
+++ b/scripts/t/600_Dpkg_Changelog.t
@@ -12,7 +12,7 @@ BEGIN {
 	+ $no_err_examples * 2
 	+ 24 # countme
 	+  2 # fields
-	+ 24;
+	+ 26;
 
     require Test::More;
     import Test::More tests => $no_tests;
@@ -20,6 +20,7 @@ BEGIN {
 BEGIN {
     use_ok('Dpkg::Changelog');
     use_ok('Dpkg::Changelog::Debian');
+    use_ok('Dpkg::Vendor');
 };
 
 my $srcdir = $ENV{srcdir} || '.';
@@ -31,6 +32,21 @@ my $test = Dpkg::Changelog::Debian->init( { infile => '/nonexistant',
 					    quiet => 1 } );
 ok( !defined($test), "fatal parse errors lead to init() returning undef");
 
+my $expect_launchpad_bugs_fixed;
+my $info = Dpkg::Vendor::get_vendor_info(Dpkg::Vendor::get_current_vendor());
+ok( $info, "can retrieve vendor info" );
+if ($info->{Vendor} eq 'Ubuntu') {
+    $expect_launchpad_bugs_fixed = 1;
+} else {
+    while (defined($info) && exists $info->{Parent}) {
+	$info = Dpkg::Vendor::get_vendor_info($info->{Parent});
+	if ($info->{Vendor} eq 'Ubuntu') {
+	    $expect_launchpad_bugs_fixed = 1;
+	    last;
+	}
+    }
+}
+
 my $save_data;
 foreach my $file ("$srcdir/countme", "$srcdir/shadow", "$srcdir/fields",
     "$srcdir/regressions") {
@@ -169,14 +185,21 @@ Urgency: high
 Maintainer: Frank Lichtenheld <frank@lichtenheld.de>
 Date: Sun, 13 Jan 2008 15:49:19 +0100
 Closes: 1000000 1111111 1111111 2222222 2222222
-Changes: 
+';
+	if ($expect_launchpad_bugs_fixed) {
+	    $expected .= 'Launchpad-Bugs-Fixed: 12345 54321 424242 2424242
+';
+	}
+	$expected .= 'Changes: 
  fields (2.0-0etch1) stable; urgency=low
  .
    * Upload to stable (Closes: #1111111, #2222222)
+   * Fix more stuff. (LP: #54321, #2424242)
  .
  fields (2.0-1) unstable; urgency=medium
  .
    * Upload to unstable (Closes: #1111111, #2222222)
+   * Fix stuff. (LP: #12345, #424242)
  .
  fields (2.0~b1-1) unstable; urgency=low,xc-userfield=foobar
  .
@@ -197,10 +220,16 @@ Urgency: medium
 Maintainer: Frank Lichtenheld <djpig@debian.org>
 Date: Sun, 12 Jan 2008 15:49:19 +0100
 Closes: 1111111 2222222
-Changes: 
+';
+	if ($expect_launchpad_bugs_fixed) {
+	    $expected .= 'Launchpad-Bugs-Fixed: 12345 424242
+';
+	}
+	$expected .= 'Changes: 
  fields (2.0-1) unstable; urgency=medium
  .
    * Upload to unstable (Closes: #1111111, #2222222)
+   * Fix stuff. (LP: #12345, #424242)
  .
  fields (2.0~b1-1) unstable; urgency=low,xc-userfield=foobar
  .
diff --git a/scripts/t/600_Dpkg_Changelog/fields b/scripts/t/600_Dpkg_Changelog/fields
index 5f08b71..5072755 100644
--- a/scripts/t/600_Dpkg_Changelog/fields
+++ b/scripts/t/600_Dpkg_Changelog/fields
@@ -1,12 +1,14 @@
 fields (2.0-0etch1) stable; urgency=low
 
   * Upload to stable (Closes: #1111111, #2222222)
+  * Fix more stuff. (LP: #54321, #2424242)
 
  -- Frank Lichtenheld <frank@lichtenheld.de>  Sun, 13 Jan 2008 15:49:19 +0100
 
 fields (2.0-1) unstable; urgency=medium
 
   * Upload to unstable (Closes: #1111111, #2222222)
+  * Fix stuff. (LP: #12345, #424242)
 
  -- Frank Lichtenheld <djpig@debian.org>  Sun, 12 Jan 2008 15:49:19 +0100
 
-- 
1.6.3.3

